@@ -50,7 +50,7 @@ Example (Low-level API - For advanced usage):
 For detailed documentation, see the README.md file and the tutorial notebooks/scripts.
 """
 
-__version__ = "0.2.0"
+__version__ = "0.2.2"
 
 from .config import DFMConfig, SeriesConfig, BlockConfig, Params, DEFAULT_GLOBAL_BLOCK_NAME
 from .config import (
@@ -69,7 +69,7 @@ from .kalman import run_kf, skf, fis, miss_data
 from .news import update_nowcast, news_dfm, para_const
 
 # Import high-level API (extends core DFM with convenience methods)
-from .dfm_api import DFM, _dfm_instance, from_yaml, from_spec, from_spec_df, from_dict
+from .api import DFM, _dfm_instance, from_yaml, from_spec, from_spec_df, from_dict
 
 # Module-level API: expose singleton instance methods and properties
 # This allows: import dfm_python as dfm; dfm.load_config(...); dfm.result
